@@ -30,11 +30,12 @@
 import os
 import glob
 import re
+import sys
 from urllib.parse import urlparse
 
 from PyQt5.QtCore import QSize, Qt, QPoint
 from PyQt5.QtGui import *
-from PyQt5.QtWidgets import QTreeView, QMessageBox, QAbstractItemView, QMenu, QSizePolicy
+from PyQt5.QtWidgets import QTreeView, QMessageBox, QAbstractItemView, QMenu, QSizePolicy, QHeaderView
 import openshot  # Python module for libopenshot (required video editing module installed separately)
 
 from classes.query import File
@@ -81,6 +82,15 @@ class FilesTreeView(QTreeView):
         if self.selected:
             # If file selected, show file related options
             menu.addSeparator()
+
+            # Add edit title option (if svg file)
+            selected_file_id = self.win.selected_files[0]
+            file = File.get(id=selected_file_id)
+            if file.data.get("path").endswith(".svg"):
+                menu.addAction(self.win.actionEditTitle)
+                menu.addAction(self.win.actionDuplicateTitle)
+                menu.addSeparator()
+
             menu.addAction(self.win.actionPreview_File)
             menu.addAction(self.win.actionSplitClip)
             menu.addAction(self.win.actionAdd_to_Timeline)
@@ -267,8 +277,8 @@ class FilesTreeView(QTreeView):
             file_url = urlparse(uri.toString())
             if file_url.scheme == "file":
                 filepath = file_url.path
-                if filepath[0] == "/" and ":" in filepath:
-                    filepath = filepath[1:]
+                if sys.platform == "win32":
+                    filepath = filepath[1:] # Remove / at beginning of path (just for Windows)
                 if os.path.exists(filepath.encode('UTF-8')) and os.path.isfile(filepath.encode('UTF-8')):
                     log.info('Adding file: {}'.format(filepath))
                     if self.add_file(filepath):
@@ -299,8 +309,18 @@ class FilesTreeView(QTreeView):
             self.resize_contents()
 
     def resize_contents(self):
-        self.resizeColumnToContents(2)
-        self.resizeColumnToContents(1)
+        # Get size of widget
+        thumbnail_width = 78
+        tags_width = 75
+
+        # Resize thumbnail and tags column
+        self.header().resizeSection(0, thumbnail_width)
+        self.header().resizeSection(2, tags_width)
+
+        # Set stretch mode on certain columns
+        self.header().setStretchLastSection(False)
+        self.header().setSectionResizeMode(1, QHeaderView.Stretch)
+        self.header().setSectionResizeMode(2, QHeaderView.Interactive)
 
     def currentChanged(self, selected, deselected):
         log.info('currentChanged')
@@ -339,7 +359,10 @@ class FilesTreeView(QTreeView):
 
     def prepare_for_delete(self):
         """Remove signal handlers and prepare for deletion"""
-        self.files_model.model.ModelRefreshed.disconnect()
+        try:
+            self.files_model.model.ModelRefreshed.disconnect()
+        except:
+            pass
 
     def __init__(self, *args):
         # Invoke parent init
@@ -365,7 +388,8 @@ class FilesTreeView(QTreeView):
         self.setSelectionBehavior(QTreeView.SelectRows)
         self.setSelectionMode(QAbstractItemView.ExtendedSelection)
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
-        self.setWordWrap(True)
+        self.setWordWrap(False)
+        self.setTextElideMode(Qt.ElideRight)
         self.setStyleSheet('QTreeView::item { padding-top: 2px; }')
         self.files_model.model.ModelRefreshed.connect(self.refresh_columns)
 
